@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2006 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1271,7 +1271,11 @@ gm_conf_init ()
   gm_conf_set_bool ("/desktop/gnome/interface/menus_have_icons", TRUE);
 
   /* automatic savings */
+#if GLIB_CHECK_VERSION (2, 14, 0)
+  g_timeout_add_seconds (5, (GSourceFunc)saveconf_timer_callback, NULL);
+#else
   g_timeout_add (5000, (GSourceFunc)saveconf_timer_callback, NULL);
+#endif
 
 }
 
