@@ -88,6 +88,8 @@ struct _EkigaAssistantPrivate
 
   GtkWidget *video_device;
 
+  gint last_active_page;
+
   GtkListStore *summary_model;
   std::vector<sigc::connection> connections;
 };
@@ -341,17 +343,7 @@ static void
 name_changed_cb (GtkEntry     *entry,
                  GtkAssistant *assistant)
 {
-  gchar **couple;
-  gboolean complete;
-
-  couple = g_strsplit (gtk_entry_get_text (entry), " ", 2);
-
-  complete = couple && couple[0] && couple[1]
-          && !PString (couple[0]).Trim ().IsEmpty ()
-          && !PString (couple[1]).Trim ().IsEmpty ();
-  set_current_page_complete (assistant, complete);
-
-  g_strfreev (couple);
+  set_current_page_complete (assistant, (gtk_entry_get_text (entry))[0] != '\0');
 }
 
 
@@ -394,12 +386,15 @@ create_personal_data_page (EkigaAssistant *assistant)
 static void
 prepare_personal_data_page (EkigaAssistant *assistant)
 {
-  gchar *full_name;
+  gchar* full_name = gm_conf_get_string (PERSONAL_DATA_KEY "full_name");
 
-  full_name = gm_conf_get_string (PERSONAL_DATA_KEY "full_name");
+  if (full_name == NULL || strlen (full_name) == 0) {
 
-  if (full_name)
-    gtk_entry_set_text (GTK_ENTRY (assistant->priv->name), full_name);
+    g_free (full_name);
+    full_name = g_strdup (g_get_real_name ());
+  }
+
+  gtk_entry_set_text (GTK_ENTRY (assistant->priv->name), full_name);
 
   g_free (full_name);
 }
@@ -634,7 +629,7 @@ static void
 prepare_ekiga_net_page (EkigaAssistant *assistant)
 {
   gmref_ptr<Opal::Bank> bank = assistant->priv->core->get ("opal-account-store");
-  Opal::Account* account = bank->find_account ("ekiga.net");
+  Opal::AccountPtr account = bank->find_account ("ekiga.net");
 
   if (account && !account->get_username ().empty ())
     gtk_entry_set_text (GTK_ENTRY (assistant->priv->username), account->get_username ().c_str ());
@@ -651,8 +646,8 @@ static void
 apply_ekiga_net_page (EkigaAssistant *assistant)
 {
   gmref_ptr<Opal::Bank> bank = assistant->priv->core->get ("opal-account-store");
-  Opal::Account* account = bank->find_account ("ekiga.net");
-  bool new_account = (account == NULL);
+  Opal::AccountPtr account = bank->find_account ("ekiga.net");
+  bool new_account = !account;
 
   if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (assistant->priv->skip_ekiga_net))) {
 	if (new_account)
@@ -778,7 +773,7 @@ static void
 prepare_ekiga_out_page (EkigaAssistant *assistant)
 {
   gmref_ptr<Opal::Bank> account_core = assistant->priv->core->get ("opal-account-store");
-  Opal::Account* account = account_core->find_account ("sip.diamondcard.us");
+  Opal::AccountPtr account = account_core->find_account ("sip.diamondcard.us");
 
   if (account && !account->get_username ().empty ())
     gtk_entry_set_text (GTK_ENTRY (assistant->priv->dusername), account->get_username ().c_str ());
@@ -796,8 +791,8 @@ apply_ekiga_out_page (EkigaAssistant *assistant)
 {
   /* Some specific Opal stuff for the Ekiga.net account */
   gmref_ptr<Opal::Bank> bank = assistant->priv->core->get ("opal-account-store");
-  Opal::Account* account = bank->find_account ("sip.diamondcard.us");
-  bool new_account = (account == NULL);
+  Opal::AccountPtr account = bank->find_account ("sip.diamondcard.us");
+  bool new_account = !account;
 
   if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (assistant->priv->skip_ekiga_out))) {
 	if (new_account)
@@ -1297,7 +1292,7 @@ convert_string_list (const std::vector<std::string> & list)
   gchar **array = NULL;
   unsigned i;
 
-  array = (gchar**) malloc (sizeof(gchar*) * (list.size() + 1));
+  array = (gchar**) g_malloc (sizeof(gchar*) * (list.size() + 1));
   for (i = 0; i < list.size(); i++)
     array[i] = (gchar*) list[i].c_str();
   array[i] = NULL;
@@ -1464,6 +1459,7 @@ ekiga_assistant_init (EkigaAssistant *assistant)
   gtk_window_set_position (GTK_WINDOW (assistant), GTK_WIN_POS_CENTER);
   gtk_container_set_border_width (GTK_CONTAINER (assistant), 12);
 
+  assistant->priv->last_active_page = 0;
   assistant->priv->icon = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
                                                     "ekiga", 48,
                                                     (GtkIconLookupFlags) 0, NULL);
@@ -1487,7 +1483,8 @@ ekiga_assistant_prepare (GtkAssistant *gtkassistant,
                          GtkWidget    *page)
 {
   EkigaAssistant *assistant = EKIGA_ASSISTANT (gtkassistant);
-  gchar *title;
+  gchar *title = NULL;
+  bool forward = false;
 
   title = g_strdup_printf (_("Ekiga Configuration Assistant (%d of %d)"),
                            gtk_assistant_get_current_page (gtkassistant) + 1,
@@ -1496,6 +1493,13 @@ ekiga_assistant_prepare (GtkAssistant *gtkassistant,
   gtk_window_set_title (GTK_WINDOW (assistant), title);
   g_free (title);
 
+  if (assistant->priv->last_active_page < gtk_assistant_get_current_page (gtkassistant))
+    forward = true;
+  assistant->priv->last_active_page = gtk_assistant_get_current_page (gtkassistant);
+
+  if (!forward)
+    return;
+
   if (page == assistant->priv->personal_data_page) {
     prepare_personal_data_page (assistant);
     return;
